#############
API reference
#############

* :mod:`verry.affine`
* :mod:`verry.autodiff`
* :mod:`verry.function`
* :mod:`verry.integrate`
* :mod:`verry.interval`
* :mod:`verry.intervalseries`
* :mod:`verry.linalg`
* :mod:`verry.optimize`
* :mod:`verry.typing`
* :mod:`verry.misc`

.. toctree::
    :maxdepth: 1
    :hidden:

    verry.affine <affine>
    verry.autodiff <autodiff>
    verry.function <function>
    verry.integrate <integrate>
    verry.interval <interval>
    verry.intervalseries <intervalseries>
    verry.linalg <linalg>
    verry.optimize <optimize>
    verry.typing <typing>
    verry.misc <misc>
